@@ -461,7 +461,7 @@ Note: If you choose to put the config file and/or the timestamp\n\
       file in the directory to synchronize, NcFTPSyncPut will _not_\n\
       upload those files _if_ they are detected.\n");
 	(void) fprintf(fp, "\nLibrary version: %s.\n", gLibNcFTPVersion + 5);
-	(void) fprintf(fp, "\nThis is a freeware program by Mike Gleason (mgleason@ncftp.com).\n");
+	(void) fprintf(fp, "\nThis is a freeware program by Mike Gleason (http://www.NcFTP.com/contact/).\n");
 	(void) fprintf(fp, "This was built using LibNcFTP (http://www.ncftp.com/libncftp).\n");
 
 	ClosePager(fp);
